@@ -273,7 +273,12 @@ def process_version(versionstr):
         new_version = str(major) + '.' + str(minor) + '.' + str(patch) + '.' + str(build)
         
     if prelease_version != '' and (__main__.change_type == 'prerelease' or __main__.change_type == 'auto'):
-        new_version = new_version + '-' + prelease_version
+        if prelease_version.startswith("+"):
+            new_version = new_version + prelease_version
+        elif prelease_version.startswith("-"):
+            new_version = new_version + prelease_version
+        else:
+            new_version = new_version + '-' + prelease_version
     
     if __main__.arch_type == 'flutter':
         new_version = new_version + "+" + str(versionCode)
